//----------------------
//
//
//----------------------


/**
 * Moonfoxのログ格納ディレクトリルートを返します。
 */
function getMoonfoxLogRoot() {
	var logRoot = null;
	
	try {
		var logdir = getPref("moonfox.logdir");
		
		if(logdir && logdir != "") {
			try {
				logRoot = new File(logdir);
			} catch(ex) {
				logRoot = null;
			}
		}
		
		//設定されていない場合
		if(!logRoot || !logRoot.exist()) {
			var profFile = new File(CM_IO_PROFD);
			var mfRoot = new File(profFile, "moonfox");
			
			if(!mfRoot.exist())
				mfRoot.mkdir();
		
			logRoot = new File(mfRoot, "log");
		}
		
		if(!logRoot.exist())
			logRoot.mkdir();
		
	} catch(e) {
		throw e;
	}
	
	return logRoot;
}

/**
 * ログファイルを読み込みRecordオブジェクトの配列として返します。
 * @param {Object} threadName
 * @param {Object} logFile
 */
function docToRecordList(doc) {
	var mfRecList = new Array();
	
	if(!doc)
		return mfRecList;

	//スレッド名取得
	var threadName = doc.getElementsByTagName("mflog")[0].getAttribute("name");
	
	var recElems = doc.getElementsByTagName("record");
	
	for(var i = 0; i < recElems.length; i++) {
		var record = new Record(threadName);
		record.init(recElems[i]);
		mfRecList.push(record);
	}
	
	return mfRecList;
}

/**
 * 
 * @param {Object} doc
 */
function writeLogHistory(threadName, file, doc) {
	try {
		var recordElems = doc.getElementsByTagName("record");
		
		if(!recordElems || recordElems.length == 0)
			return;
		else {
			var deleteCnt = recordElems.length - MF_LOG_HISTORY_COUNT;
			
			if(deleteCnt > 0)
				recordElems = recordElems.slice(deleteCnt);
		}
		
		var out = file.establishConverterOutputStream("UTF-8");
	    out.writeString("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
		out.writeString("<!DOCTYPE mflog SYSTEM \"chrome://moonfox/content/moonfox_log_history.dtd\">\n");
		
	    out.writeString("<mflog-history name=\"" + threadName + "\">\n");
		
		for(var i = 0; i < recordElems.length; i++) {
			var id = recordElems[i].getAttribute("id");
			
			if(!id || id == "")
				continue;
			
			out.writeString("<record id=\"");
			out.writeString(id);
			out.writeString("\"/>\n");
		}
		
		out.writeString("/mflog-history>");
	} catch(e) {
		throw e;
	}
}

/**
 * 
 * @param {Object} cacheFile
 * @param {Object} recList
 */
function writeRecordList(threadName, logFile, recList) {
	try {
		var out = logFile.establishConverterOutputStream("UTF-8");
	    out.writeString("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
		out.writeString("<!DOCTYPE mflog SYSTEM \"chrome://moonfox/content/moonfox_log.dtd\">\n");
		
	    out.writeString("<mflog name=\"" + threadName + "\">\n");
	    
	    for(var i = 0; i < recList.length; i++) {
	    	out.writeString("<record ");
	    	out.writeString("id=\"" + recList[i].id + "\" ");
	    	out.writeString("stamp=\"" + recList[i].stamp + "\" ");
	    	out.writeString("hash=\"" + recList[i].hash + "\" ");
			out.writeString("no=\"" + recList[i].no + "\" ");
			out.writeString("attach=\"" + recList[i].attach + "\" ");
			
			if(recList[i].name)
	    		out.writeString("name=\"" + recList[i].name + "\" ");
			
			if(recList[i].mail)
	    		out.writeString("mail=\"" + recList[i].mail + "\" ");
			
			if(recList[i].suffix)
				out.writeString("suffix=\"" + recList[i].suffix + "\" ");
			
			if(recList[i].pubkey)
				out.writeString("pubkey=\"" + recList[i].pubkey + "\" ");
			
			if(recList[i].sign)
				out.writeString("sign=\"" + recList[i].sign + "\" ");
			
			if(recList[i].target)
				out.writeString("target=\"" + recList[i].target + "\" ");
			
			if(recList[i].removeHash)
				out.writeString("removeHash=\"" + recList[i].removeHash + "\" ");
			
			if(recList[i].removeStamp)
				out.writeString("removeStamp=\"" + recList[i].removeStamp + "\" ");
			
			out.writeString("delete=\"" + recList[i].deleteFlg + "\" ");
	    	out.writeString(">\n");
			
			if(recList[i].body) {
				out.writeString("<body>\n");
				out.writeString("<![CDATA[");
				out.writeString(recList[i].body);
				out.writeString("]]>\n");
				out.writeString("</body>\n");
			}
			
			out.writeString("</record>\n");
	    }
	    
	    out.writeString("</mflog>");
	    
	    out.close();
	} catch(e) {
		throw e;
	}
}